% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid-build.R
\docType{class}
\name{hexagrid-class}
\alias{hexagrid-class}
\alias{hexagrid}
\title{Construct a penta-hexagonal icosahedral grid}
\arguments{
\item{tessellation}{(\code{numeric}) An integer vector with the tessellation values. Each number
 describes the number of new edges replacing one original edge. Multiple series of tessellations
    are possible this way. The total tessellation is the product of the tessellation vector. 
Higher values result in more uniform cell sizes, but the larger number of tessellation series,
increases the speed of lookup functions.}

\item{deg}{(\code{numeric}) The target edge length of the grid in degrees. If provided, the function will select the appropriate tessellation vector from the \code{\link{hexguide}}-table, which is closest to the target. Note that these are unlikely to be the exact matches.}

\item{sp}{(\code{logical}) Flag indicating whether the \code{\link[sp]{SpatialPolygons}} class representation of the grid
should be added to the object when the grid is calculated. If set to true the \code{\link{SpPolygons}} function will be run with with the resolution parameter set to \code{25}. The 
 resulting object will be stored in slot \code{@sp}. As the calculation of this object can increase the grid creation time substantially
 by default this argument has a value \code{FALSE}. This can be added on demand by running the function \code{\link{newsp}}.}

\item{graph}{(\code{logical}) Flag indicating whether the \code{\link[igraph:aaa-igraph-package]{igraph}} class representation of the grid
should be added to the object when the grid is calculated. This argument defaults to \code{TRUE} because this option has only minor performance load on the grid 
constructor function. For familiarization with the
object structure, however, setting this parameter to \code{FALSE} might help, as invoking \code{\link[utils]{str}} on the 'igraph' class slot of the class might flood the console.}

\item{radius}{(\code{numeric}) The radius of the grid. Defaults to the authalic radius of Earth.}

\item{center}{(\code{numeric}) The origin of the grid in the reference Cartesian coordinate system. Defaults to \code{c(0,0,0)}.}

\item{verbose}{(\code{logical}) Should messages be printed during grid creation?}
}
\value{
A hexagonal grid object, with class \code{hexagrid}.
}
\description{
The \code{hexagrid} function constrcucts a hexa-pentagonal grid based on the inversion of a 
   tessellated icosahedron.
}
\details{
Inherits from the \code{trigrid} class.

The grid structure functions as a frame for data graining, plotting and
calculations. Data can be stored in layers that are linked to the grid object. In the current version only the 
\code{\link{facelayer}} class is implemented which allows the user to render data to the cells
of the grid which are called faces. 
	The grid 'user interface' is made up of four primary tables: the \code{@vertices} table for the coordinates of the vertices,
	the \code{faceCenters} for the coordinates of the centers of faces,
the \code{faces} and the \code{edges} tables that contain which vertices form which faces and edges respectively.
In these tables, the faces and vertices are sorted to form spirals that go from the north pole in a counter-clockwise
direction. In case grid subsetting is performed these tables get truncated.

At finer resolutions, the large number of spatial elements render all calculations very resource demanding and slow, 
therefore the hierarchical structure created during the tessellation procedure is retained for efficient implementations.
These data are stored in a list in the slot \code{@skeleton} and are 0-indexed integer tables for Rccp-based functions. \code{$v} 
stores vertex, \code{$f} the edge, and \code{$e} contains the edge data for plotting and calculations. In these tables
the original hierarchy based orderings of the units are retained, during subsetting, additional vectors are used to indicate
deactivation of these units. Any sort of meddling with the @skeleton object will lead to unexpected behavior.
}
\section{Slots}{

\describe{
\item{\code{vertices}}{Matrix of the vertex coordinates.}

\item{\code{faces}}{Matrix of the verticies forming the faces}

\item{\code{edges}}{Matrix of the vertices forming the edges.}

\item{\code{tessellation}}{Contains the tessellation vector.}

\item{\code{orientation}}{Contains the grid orientation in xyz 3d space, values in radian.}

\item{\code{center}}{The xyz coordinates of the grid's origin/center.}

\item{\code{div}}{Contains the number of faces that a single face of the previous tessellation level is decomposed to.}

\item{\code{faceCenters}}{Contains the xyz coordinates of the centers of the faces on the surface of the sphere.}
}}

\examples{
g <- hexagrid(c(8), sf=TRUE)
# based on approximate size (4 degrees edge length)
g1 <- hexagrid(deg=4) 
}
